provide_root_context

Function provide_root_context 

pub fn provide_root_context<T>(value: T)
where T: Clone + 'static,
Store the given value in the root scope.

Only needed for specific cases like values consumed by queries or mutations, which run in the root scope. Prefer provide_context otherwise.