use_provide_root_context

Function use_provide_root_context 

pub fn use_provide_root_context<T>(init: impl FnOnce() -> T) -> T
where T: Clone + 'static,
Store the given value in the root scope.

Only needed for specific cases like values consumed by queries or mutations, which run in the root scope. Prefer use_provide_context otherwise.