Struct Platform
pub struct Platform {
pub focused_accessibility_id: State<NodeId>,
pub focused_accessibility_node: State<Node>,
pub root_size: State<Size2D<f32, ()>>,
pub navigation_mode: State<NavigationMode>,
pub preferred_theme: State<PreferredTheme>,
pub sender: Rc<dyn Fn(UserEvent)>,
}Expand description
Access point to different Freya-managed states such as the focused node, root window size, navigation mode, and theme preference.
Retrieve it from any component with Platform::get.
Fields
focused_accessibility_id: State<NodeId>The AccessibilityId of the currently focused node.
focused_accessibility_node: State<Node>The accessibility node data of the currently focused node.
root_size: State<Size2D<f32, ()>>The size of the root window.
The current NavigationMode.
preferred_theme: State<PreferredTheme>The OS-level PreferredTheme.
sender: Rc<dyn Fn(UserEvent)>Internal sender used to dispatch UserEvents.
Implementations