Struct TransformOrigin
pub struct TransformOrigin {
pub x: OriginValue,
pub y: OriginValue,
}Expand description
Reference point that the scale and rotation effects of an element pivot around.
Defaults to the element’s center.
Fields
x: OriginValuey: OriginValueImplementations
impl TransformOrigin
impl TransformOrigin
pub fn origin(&self, area: &Rect<f32, ()>) -> Point2D<f32, ()>
pub fn origin(&self, area: &Rect<f32, ()>) -> Point2D<f32, ()>
Resolve the origin point in absolute coordinates for the given element area.
pub fn center() -> TransformOrigin
pub fn top_left() -> TransformOrigin
pub fn top() -> TransformOrigin
pub fn top_right() -> TransformOrigin
pub fn left() -> TransformOrigin
pub fn right() -> TransformOrigin
pub fn bottom_left() -> TransformOrigin
pub fn bottom() -> TransformOrigin
pub fn bottom_right() -> TransformOrigin