Struct LaunchConfig
pub struct LaunchConfig { /* private fields */ }Expand description
Configuration for the initial state of the application.
Use this to register windows, plugins, fonts, and other settings that should be ready before the application starts.
Implementations
impl LaunchConfig
impl LaunchConfig
pub fn new() -> LaunchConfig
pub fn window_icon(icon: &[u8]) -> Icon
pub fn window_icon(icon: &[u8]) -> Icon
Load a window icon from image bytes. Pass the result to WindowConfig::with_icon.
pub fn tray_icon(icon: &[u8]) -> Icon
tray only.impl LaunchConfig
impl LaunchConfig
pub fn with_window(self, window_config: WindowConfig) -> LaunchConfig
pub fn with_window(self, window_config: WindowConfig) -> LaunchConfig
Register a window configuration. You can call this multiple times.
To create windows dynamically after the application has started,
see crate::extensions::WinitPlatformExt::launch_window().
pub fn with_tray(
self,
tray_icon: impl FnOnce() -> TrayIcon + Send + 'static,
tray_handler: impl FnMut(TrayEvent, RendererContext<'_>) + 'static,
) -> LaunchConfig
Available on crate feature tray only.
pub fn with_tray( self, tray_icon: impl FnOnce() -> TrayIcon + Send + 'static, tray_handler: impl FnMut(TrayEvent, RendererContext<'_>) + 'static, ) -> LaunchConfig
tray only.Register a tray icon and its handler.
pub fn with_plugin(self, plugin: impl FreyaPlugin + 'static) -> LaunchConfig
pub fn with_plugin(self, plugin: impl FreyaPlugin + 'static) -> LaunchConfig
Register a plugin. Replaces any existing plugin with the same ID.
pub fn with_font(
self,
font_name: impl Into<Cow<'static, str>>,
font: impl Into<Bytes>,
) -> LaunchConfig
pub fn with_font( self, font_name: impl Into<Cow<'static, str>>, font: impl Into<Bytes>, ) -> LaunchConfig
Embed a font.
pub fn with_fallback_font(
self,
font_family: impl Into<Cow<'static, str>>,
) -> LaunchConfig
pub fn with_fallback_font( self, font_family: impl Into<Cow<'static, str>>, ) -> LaunchConfig
Register a fallback font. Will be used if the default fonts are not available.
pub fn with_default_font(
self,
font_name: impl Into<Cow<'static, str>>,
) -> LaunchConfig
pub fn with_default_font( self, font_name: impl Into<Cow<'static, str>>, ) -> LaunchConfig
Register a default font. Will be used if found.
pub fn with_exit_on_close(self, exit_on_close: bool) -> LaunchConfig
pub fn with_exit_on_close(self, exit_on_close: bool) -> LaunchConfig
Whether to exit the event loop when all windows are closed. Defaults to true.
Set to false to keep the event loop alive even when no windows remain.
pub fn with_future<F, Fut>(self, task: F) -> LaunchConfig
pub fn with_future<F, Fut>(self, task: F) -> LaunchConfig
Register a single-thread launch task.
The task receives a [LaunchProxy] that can be used to get access to RendererContext.
The provided callback should return a 'static future which will be scheduled on the renderer
thread and polled until completion.
pub fn with_event_loop(self, event_loop: EventLoop<NativeEvent>) -> LaunchConfig
pub fn with_event_loop(self, event_loop: EventLoop<NativeEvent>) -> LaunchConfig
Provide a custom winit EventLoop to use instead of the default one. This allows configuring platform-specific options on the event loop builder before passing it.